@@ -40,7 +40,6 @@ from ai.h2o.sparkling.ml.models.H2OIsolationForestMOJOModel import H2OIsolationF
 from ai.h2o.sparkling.ml.models.H2OAutoEncoderMOJOModel import H2OAutoEncoderMOJOModel
 from ai.h2o.sparkling.ml.models.H2OPCAMOJOModel import H2OPCAMOJOModel
 from ai.h2o.sparkling.ml.models.H2OGLRMMOJOModel import H2OGLRMMOJOModel
-from ai.h2o.sparkling.ml.models.H2OWord2VecMOJOModel import H2OWord2VecMOJOModel
 
 
 class H2OMOJOModelFactory:
@@ -94,8 +93,6 @@ class H2OMOJOModelFactory:
             return H2OPCAMOJOModel(javaModel)
         elif className == "H2OGLRMMOJOModel":
             return H2OGLRMMOJOModel(javaModel)
-        elif className == "H2OWord2VecMOJOModel":
-            return H2OWord2VecMOJOModel(javaModel)
         else:
             return H2OMOJOModel(javaModel)
 
