@@ -24,11 +24,11 @@ class H2OMOJOSettings(JavaWrapper):
     def __init__(self,
                  predictionCol="prediction",
                  detailedPredictionCol="detailed_prediction",
+                 withDetailedPredictionCol=True,
                  convertUnknownCategoricalLevelsToNa=False,
                  convertInvalidNumbersToNa=False,
                  namedMojoOutputColumns=True,
                  withContributions=False,
-                 withInternalContributions=False,
                  withLeafNodeAssignments=False,
                  withStageResults=False,
                  dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer"):
@@ -40,7 +40,6 @@ class H2OMOJOSettings(JavaWrapper):
         assert isinstance(convertInvalidNumbersToNa, bool)
         assert isinstance(namedMojoOutputColumns, bool)
         assert isinstance(withContributions, bool)
-        assert isinstance(withInternalContributions, bool)
         assert isinstance(withLeafNodeAssignments, bool)
         assert isinstance(withStageResults, bool)
         assert isinstance(dataFrameSerializer, str)
@@ -50,7 +49,6 @@ class H2OMOJOSettings(JavaWrapper):
         self.convertInvalidNumbersToNa = convertInvalidNumbersToNa
         self.namedMojoOutputColumns = namedMojoOutputColumns
         self.withContributions = withContributions
-        self.withInternalContributions = withInternalContributions
         self.withLeafNodeAssignments = withLeafNodeAssignments
         self.withStageResults = withStageResults
         self.dataFrameSerializer = dataFrameSerializer
@@ -59,11 +57,11 @@ class H2OMOJOSettings(JavaWrapper):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.models.H2OMOJOSettings",
                                             self.predictionCol,
                                             self.detailedPredictionCol,
+                                            True,
                                             self.convertUnknownCategoricalLevelsToNa,
                                             self.convertInvalidNumbersToNa,
                                             self.namedMojoOutputColumns,
                                             self.withContributions,
-                                            self.withInternalContributions,
                                             self.withLeafNodeAssignments,
                                             self.withStageResults,
                                             self.dataFrameSerializer)
